5. Py4J Java API — Py4J

Py4J - A Bridge between Python and Java

### Navigation

- index
- modules |
- next |
- previous |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »

# 5. Py4J Java API

The Java API is under active development and will be refactored in the next releases. You can browse the javadoc, but most classes are not documented yet.

For now, the best way to use the API is to:

1. Create a class that extends the DefaultGateway.
2. Initialize a GatewayServer with your newly created class.
3. Call the Gateway.start() method to enable your Python program to access your gateway.

### Questions/Feedback?

- Try the FAQ -- It answers many questions.
- Search for information in the archives of the py4j-users mailing list, or post a question.
- If you notice errors with this documentation, open a ticket and let us know. Please, only open a ticket for feedback or improvements on the docs. To get help, use the links above!
- Request professional services to get a custom feature implemented quickly or to receive commercial support.

### Navigation

- index
- modules |
- next |
- previous |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »